@@ -266,12 +266,14 @@ class Campaign:
         self,
         id: int,
         name: str,
+        drip_count: int,
         send_if_duplicate: bool,
         has_anniversary_drip: bool = False,
         has_birthday_drip: bool = False,
     ) -> None:
         self._id = id
         self._name = name
+        self._drip_count = drip_count
         self._send_if_duplicate = send_if_duplicate
         self._has_anniversary_drip = has_anniversary_drip
         self._has_birthday_drip = has_birthday_drip
@@ -288,6 +290,11 @@ class Campaign:
         """Drip campaign's name."""
         return self._name
 
+    @property
+    def drip_count(self) -> int:
+        """Drip campaign's drip count."""
+        return self._drip_count
+
     @property
     def send_if_duplicate(self) -> bool:
         """If True, AMcards will not attempt to detect and prevent duplicates. Otherwise, if this campaign has been previously sent to a contact, further campaign send attempts to the same contact will be prevented."""
@@ -308,6 +315,7 @@ class Campaign:
         return cls(
             id=json['id'],
             name=json['title'],
+            drip_count=json['drip_count'],
             send_if_duplicate=json['send_even_if_duplicate'],
             has_anniversary_drip=json['has_anniversary_drip'],
             has_birthday_drip=json['has_birthday_drip'],
